@@ -7,10 +7,13 @@
 using namespace Rcpp;
 using namespace arma;
 
-class Binomial : public Family {
+class Binomial : public Family
+{
 public:
-  template <typename... Ts>
-  Binomial(Ts... args) : Family(std::forward<Ts>(args)...) {}
+  template<typename... Ts>
+  Binomial(Ts... args)
+    : Family(std::forward<Ts>(args)...)
+  {}
 
   double primal(const mat& y, const mat& lin_pred)
   {
@@ -19,7 +22,7 @@ public:
 
   double dual(const mat& y, const mat& lin_pred)
   {
-    const vec r = 1.0/(1.0 + trunc_exp(y % lin_pred));
+    const vec r = 1.0 / (1.0 + trunc_exp(y % lin_pred));
     return dot(r - 1.0, trunc_log(1.0 - r)) - dot(r, trunc_log(r));
   }
 
@@ -33,13 +36,10 @@ public:
     double pmin = 1e-9;
     double pmax = 1 - pmin;
 
-    vec mu = clamp(mean(0.5*y + 0.5), pmin, pmax);
+    vec mu = clamp(mean(0.5 * y + 0.5), pmin, pmax);
 
-    return trunc_log(mu/(1.0 - mu));
+    return trunc_log(mu / (1.0 - mu));
   }
 
-  std::string name()
-  {
-    return "binomial";
-  }
+  std::string name() { return "binomial"; }
 };
