@@ -5,7 +5,8 @@
 using namespace Rcpp;
 using namespace arma;
 
-inline mat prox(const mat& beta, const vec& lambda)
+inline mat
+prox(const mat& beta, const vec& lambda)
 {
   uword p = beta.n_elem;
 
@@ -27,14 +28,14 @@ inline mat prox(const mat& beta, const vec& lambda)
   for (uword i = 0; i < p; i++) {
     idx_i(k) = i;
     idx_j(k) = i;
-    s(k)     = beta_vec(i) - lambda(i);
-    w(k)     = s(k);
+    s(k) = beta_vec(i) - lambda(i);
+    w(k) = s(k);
 
     while ((k > 0) && (w(k - 1) <= w(k))) {
       k--;
-      idx_j(k)  = i;
-      s(k)     += s(k + 1);
-      w(k)      = s(k) / (i - idx_i(k) + 1.0);
+      idx_j(k) = i;
+      s(k) += s(k + 1);
+      w(k) = s(k) / (i - idx_i(k) + 1.0);
     }
     k++;
   }
@@ -54,4 +55,3 @@ inline mat prox(const mat& beta, const vec& lambda)
   // reset sign and return
   return reshape(beta_vec, size(beta));
 }
-
